# shor
The Python quantum computing library.

Shor is a simple, modular, and extensible quantum computing API written in python.

#### Our mission is to make quantum computing easy and accesible to everyone.


Use shor if you need a library that:
- Enables fast prototyping of quantum circuits
- Simulates small quantum programs
- Makes quantum computing easy


In the near future we plan to support running your programs on real world quantum computers.
Write your program once, and run it anywhere.

Read the documentation, view tutorials and examples, and join the community at: https://shor.dev/

We are in early development and looking for contributors!

Shor is compatible with Python 3.6 and is distributed under the MIT license.